OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
    "See %s" : "Погледајте %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
    "Sample configuration detected" : "Откривен је пример подешавања",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
    "Other activities" : "Остале активности",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education Edition" : "Образовно издање",
    "Enterprise bundle" : "Комплет за предузећа",
    "Groupware bundle" : "Комплет за радне тимове",
    "Hub bundle" : "Чвориште пакета",
    "Social sharing bundle" : "Комплет за друштвене мреже",
    "PHP %s or higher is required." : "Потребан је PHP %s или новији.",
    "PHP with a version lower than %s is required." : "Потребна је PHP верзија старија од верзије %s.",
    "%sbit or higher PHP required." : "Потребна је верзија PHP-а једнака или већа од верзије %s.",
    "The following architectures are supported: %s" : "Подржане су следеће архитектуре: %s",
    "The following databases are supported: %s" : "Подржане су следеће базе података: %s",
    "The command line tool %s could not be found" : "Алатку командне линије „%s“ није могуће пронаћи",
    "The library %s is not available." : "Библиотека „%s“ није доступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије веће од %2$s - доступна верзија је %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије ниже од %2$s - доступна верзија је %3$s.",
    "The following platforms are supported: %s" : "Подржане су следеће платформе: %s",
    "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
    "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
    "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
    "Logged in user must be an admin" : "Пријављени корисник мора бити администратор",
    "Wiping of device %s has started" : "Започето брисање уређаја %s",
    "Wiping of device »%s« has started" : "Удаљено брисање уређаја „%s“ је почело",
    "»%s« started remote wipe" : "„%s“ је започео удаљено брисање",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Уређај или апликација „%s“ је започео процес удаљеног брисања. Добићете још један и-мејл када се процес заврши.",
    "Wiping of device %s has finished" : "Брисање уређаја %s завршено",
    "Wiping of device »%s« has finished" : "Брисање уређаја „%s“ завршено",
    "»%s« finished remote wipe" : "„%s“ је завршио удаљено брисање",
    "Device or application »%s« has finished the remote wipe process." : "Уређај или апликација „%s“ је завршио процес удаљеног брисања.",
    "Remote wipe started" : "Започето удаљено брисање",
    "A remote wipe was started on device %s" : "Започето удаљено брисање на уређају %s",
    "Remote wipe finished" : "Удаљено брисање завршено",
    "The remote wipe on %s has finished" : "Удаљено брисање на уређају %s завршено",
    "Authentication" : "Провера идентитета",
    "Unknown filetype" : "Непознат тип фајла",
    "Invalid image" : "Неисправна слика",
    "Avatar image is not square" : "Слика аватара није квадратна",
    "View profile" : "Погледај профил",
    "today" : "данас",
    "tomorrow" : "сутра",
    "yesterday" : "јуче",
    "_in %n day_::_in %n days_" : ["за %n дан","за %n дана","за %n дана"],
    "_%n day ago_::_%n days ago_" : ["пре %n дан","пре %n дана","пре %n дана"],
    "next month" : "следећег месеца",
    "last month" : "прошлог месеца",
    "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца","за %n месеци"],
    "_%n month ago_::_%n months ago_" : ["пре %n месец","пре %n месеца","пре %n месеци"],
    "next year" : "следеће године",
    "last year" : "прошле године",
    "_in %n year_::_in %n years_" : ["за %n годину","за %n године","за %n година"],
    "_%n year ago_::_%n years ago_" : ["пре %n годину","пре %n године","пре %n година"],
    "_in %n hour_::_in %n hours_" : ["за %n сат","за %n сата","за %n сати"],
    "_%n hour ago_::_%n hours ago_" : ["пре %n сат","пре %n сата","пре %n сати"],
    "_in %n minute_::_in %n minutes_" : ["за %n минут","за %n минута","за %n минута"],
    "_%n minute ago_::_%n minutes ago_" : ["пре %n минут","пре %n минута","пре %n минута"],
    "in a few seconds" : "за пар секунди",
    "seconds ago" : "пре неколико секунди",
    "Empty file" : "Празан фајл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
    "File already exists" : "Фајл већ постоји",
    "File name is a reserved word" : "Назив фајла је резервисана реч",
    "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
    "File name is too long" : "Назив фајла је предугачак",
    "Dot files are not allowed" : "Фајлови са почетном тачком нису дозвољени",
    "Empty filename is not allowed" : "Празан назив није дозвољен",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Апликација \"%s\" не може бити инсталирана јер appinfo фајл не може да се прочита.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликација \"%s\" не може бити инсталирана јер није компатибилна са овом верзијом сервера.",
    "__language_name__" : "Српски",
    "This is an automatically sent email, please do not reply." : "Ово је аутоматски генерисана порука, не одговарајте на њу.",
    "Help" : "Помоћ",
    "Apps" : "Апликације",
    "Settings" : "Поставке",
    "Log out" : "Одјава",
    "Users" : "Корисници",
    "Email" : "Е-пошта",
    "Phone" : "Телефон",
    "Twitter" : "Твитер",
    "Website" : "Веб страна",
    "Address" : "Адреса",
    "Profile picture" : "Слика профила",
    "About" : "О програму",
    "Full name" : "Пуно име",
    "Headline" : "Наслов",
    "Unknown user" : "Непознат корисник",
    "Additional settings" : "Додатне поставке",
    "MySQL username and/or password not valid" : "MySQL корисничко име и/или лозинка нису исправни",
    "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
    "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
    "Oracle username and/or password not valid" : "Oracle корисничко име и/или лозинка нису исправни",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничко име и/или лозинка нису исправни",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Мек ОС Икс није подржан и %s неће радити исправно на овој платформи. Користите га на сопствени ризик!",
    "For the best results, please consider using a GNU/Linux server instead." : "За најбоље резултате, размотрите употребу ГНУ/Линукс сервера.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Изгледа да %s ради у 32-битном PHP окружењу а open_basedir је подешен у php.ini фајлу. То може довести до проблема са фајловима већим од 4 GB, те стога није препоручљиво.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни PHP.",
    "Set an admin username." : "Поставите име за администратора.",
    "Set an admin password." : "Поставите лозинку за администратора.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
    "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
    "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио „%2$s“ са Вама и жели да дода:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио „%2$s“ са Вама и жели да дода",
    "»%s« added a note to a file shared with you" : "\"%s\" је додао белешку на фајл који дели са Вама",
    "Open »%s«" : "Отвори „%s“",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
    "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
    "Expiration date is in the past" : "Датум истека је у прошлости",
    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
    "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
    "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
    "Click the button below to open it." : "Кликните дугме испод да га отворите.",
    "The requested share does not exist anymore" : "Захтевано дељење више не постоји",
    "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
    "Sunday" : "Недеља",
    "Monday" : "Понедељак",
    "Tuesday" : "Уторак",
    "Wednesday" : "Среда",
    "Thursday" : "Четвртак",
    "Friday" : "Петак",
    "Saturday" : "Субота",
    "Sun." : "Нед",
    "Mon." : "Пон",
    "Tue." : "Уто",
    "Wed." : "Сре",
    "Thu." : "Чет",
    "Fri." : "Пет",
    "Sat." : "Суб",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Ут",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Су",
    "January" : "Јануар",
    "February" : "Фебруар",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јун",
    "July" : "Јул",
    "August" : "Август",
    "September" : "Септембар",
    "October" : "Октобар",
    "November" : "Новембар",
    "December" : "Децембар",
    "Jan." : "Јан.",
    "Feb." : "Феб.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Мај.",
    "Jun." : "Јун.",
    "Jul." : "Јул.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Нов.",
    "Dec." : "Дец.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Морате унети исправно корисничко име",
    "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
    "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
    "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
    "A valid password must be provided" : "Морате унети исправну лозинку",
    "The username is already being used" : "Корисничко име се већ користи",
    "Could not create user" : "Не могу да направим корисника",
    "User disabled" : "Корисник онемогућен",
    "Login canceled by app" : "Пријава отказана од стране апликације",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
    "a safe home for all your data" : "сигурно место за све Ваше податке",
    "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
    "Application is not enabled" : "Апликација није укључена",
    "Authentication error" : "Грешка при провери идентитета",
    "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
    "PHP module %s not installed." : "PHP модул %s није инсталиран.",
    "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потребан је бар libxml2 2.7.0. Тренутно је инсталиран %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Да поправите овај проблем, ажурирајте верзију библиотеке libxml2 и рестартујте веб сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
    "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверите се да фајл \".ocdata\" постоји у корену директоријума са подацима.",
    "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
    "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Недостају параметри да би се довршио захтев. Недостајући параметри: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификацију \"%1$s\" већ користи провајдер здруживања \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провајдер клауд здруживања са ID-ом \"%s\" не постоји",
    "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“.",
    "Storage unauthorized. %s" : "Складиште није овлашћено. %s",
    "Storage incomplete configuration. %s" : "Непотпуна конфигурација складишта. %s",
    "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
    "This can usually be fixed by giving the webserver write access to the config directory." : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима.",
    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
    "%s enter the database username." : "%s унеси корисничко име базе података.",
    "%s enter the database name." : "%s унеси име базе података.",
    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
    "Cannot create \"data\" directory" : "Не могу да направим \"data\" директоријум",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ово се обично може поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Привилегије се обично могу поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
    "Please upgrade your database version" : "Надоградите ваше издање базе",
    "Your data directory is readable by other users" : "Директоријум са подацима је читљив од стране других корисника система",
    "Your data directory must be an absolute path" : "Директоријум са подацима мора бити апсолутна путања",
    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
    "Your data directory is invalid" : "Директоријум са подацима није исправан"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
